@@ -44,7 +44,8 @@ sub register {
     my $token = $c->stash('token');
     my $secret = $c->app->secrets->[0];
     my $hmac = hmac_sha1_sum $token, $secret;
-    $c->delay(
+    my $tx = $c->render_later->tx;
+    Mojo::IOLoop->delay(
       sub { $ua->get($url->clone->path("/$token"), {'X-HMAC' => $hmac}, shift->begin) },
       sub {
         my ($delay, $tx) = @_;
@@ -55,7 +56,7 @@ sub register {
 
         $c->render(text => $auth);
       },
-    );
+    )->catch(sub{ $c->helpers->reply->exception(pop) and undef $tx })->wait;
   });
 }
 
